@@ -1,22 +1,20 @@
 from mtmai.agents.chat_profiles.chat_post_gen import PostGenAgent
 from mtmai.agents.chat_profiles.home_agent import HomeAgent
-from mtmai.agents.chat_profiles.main_copliot_agent import MainCopilotAgent
-from mtmai.agents.chat_profiles.site_settings_agent import SiteSettingsAgent
-
-all_chat_agents = [MainCopilotAgent,PostGenAgent, SiteSettingsAgent, HomeAgent]
 
+all_chat_agents = [
+    PostGenAgent,
+    HomeAgent
+    ]
 
 async def get_all_profiles():
     all_profiles = [agent.get_chat_profile() for agent in all_chat_agents]
     return all_profiles
 
-
 async def get_default_chat_profile():
     return next(
         (profile for profile in await get_all_profiles() if profile.default), None
     )
 
-
 async def get_chat_profile_by_name(name: str):
     """
     根据名称获取聊天配置, TODO: 可能有问题
