@@ -9,7 +9,7 @@ from langgraph.graph.message import AnyMessage
 from pydantic import BaseModel, Field
 
 from mtmai.agents.ctx import get_mtmai_ctx
-from mtmai.agents.retrivers.web_search import search_engine
+from mtmai.agents.tools.web_search import search_engine
 from mtmai.core.logging import get_logger
 from mtmai.llm.llm import get_fast_llm
 from mtmai.models.graph_config import Editor, InterviewState
