@@ -3,19 +3,17 @@ from typing import Union
 from fastapi import APIRouter, Depends, Query
 from fastapi.responses import JSONResponse
 from langchain_core.messages import ChatMessage
-from typing_extensions import Annotated
-from langgraph.graph.graph import CompiledGraph
 from langchain_core.runnables import RunnableConfig
-
-
+from langgraph.graph.graph import CompiledGraph
+from typing_extensions import Annotated
 
 import mtmai.chainlit as cl
-from mtmai.chainlit import context
-from mtmai.chainlit.context import init_http_context
 import mtmai.chainlit.data as cl_data
 from mtmai.agents.chat_profiles.profiles import get_all_profiles, get_chat_agent
 from mtmai.auth import get_current_user
+from mtmai.chainlit import context
 from mtmai.chainlit.config import config
+from mtmai.chainlit.context import init_http_context
 from mtmai.chainlit.data import get_data_layer
 from mtmai.chainlit.markdown import get_markdown_str
 from mtmai.chainlit.types import GetThreadsRequest, ThreadDict
@@ -25,6 +23,7 @@ from mtmai.crud import curd_chat
 from mtmai.deps import AsyncSessionDep, CurrentUser, OptionalUserDep, SessionDep
 from mtmai.models.chat import ChatProfilesResponse
 from mtmai.models.models import User
+from mtmai.mtlibs import aisdk
 from mtmai.mtlibs.chainlit.data_layer import SQLAlchemyDataLayer
 
 # 使用自定义的 sql 存储chainlit数据
@@ -187,6 +186,7 @@ async def project_settings(
     }
     return JSONResponse(content=data_resonse)
 
+
 @router.get("/graph_image/{thread_id}")
 async def graph_image(
     thread_id: str,
@@ -196,7 +196,10 @@ async def graph_image(
     #     thread_id=thread_id,
     #     user=current_user,
     # )
-    init_http_context(user=current_user, thread_id=thread_id,)
+    init_http_context(
+        user=current_user,
+        thread_id=thread_id,
+    )
     ctx = context
     await cl.Message(content="Hello, I am a chatbot!").send()
 
@@ -214,4 +217,14 @@ async def graph_image(
     pre_state = await graph.aget_state(thread, subgraphs=True)
 
     # await self.run_graph(thread)
-    return "threadid:"+ thread_id
\ No newline at end of file
+    return "threadid:" + thread_id
+
+
+
+
+
+# @router.post("/chat")
+# async def chat():
+#     return aisdk.AiSDKStreamResponse(
+#         fake_video_streamer(),
+#     )
