@@ -7,8 +7,11 @@ from fastapi import APIRouter, HTTPException, Query
 from fastapi.responses import FileResponse
 
 from mtmai.core.config import APP_ROOT
+from mtmai.core.logging import get_logger
 from mtmai.types.types import Theme
 
+logger = get_logger()
+
 router = APIRouter()
 
 mimetypes.add_type("application/javascript", ".js")
@@ -44,3 +47,11 @@ async def get_logo(theme: Optional[Theme] = Query(Theme.light)):
     media_type, _ = mimetypes.guess_type(logo_path)
 
     return FileResponse(logo_path, media_type=media_type)
+
+
+    #merge_gauge_data(filename)
+
+@router.get("/flow_hello")
+async def flow_hello():
+    from mtmai.flows.hello_flow import flow_hello
+    flow_hello()
\ No newline at end of file
