@@ -1,16 +1,20 @@
+import asyncio
+import random
 from fastapi import APIRouter, HTTPException, Request
 from fastapi.responses import StreamingResponse
+from numpy import rec
 from openai.types.chat.chat_completion_message_param import ChatCompletionMessageParam
 from openai.types.chat.completion_create_params import CompletionCreateParamsBase
 from opentelemetry import trace
 
 from mtmai.core.logging import get_logger
-from mtmai.deps import CheckPointerDep, OptionalUserDep, SessionDep
+from mtmai.deps import OptionalUserDep, SessionDep
 from mtmai.llm.llm import (
     call_chat_completions,
     chat_completions_stream_generator,
     default_llm_model,
 )
+from mtmai.mtlibs import aisdk
 
 router = APIRouter()
 logger = get_logger()
@@ -31,13 +35,20 @@ class MtmaiCompletionRequest(CompletionCreateParamsBase):
     model: str | None = None
     stream: bool | None = False
 
+async def fake_video_streamer():
+    text = example_stream_response
+    tokens = text.split(' ')
+
+    for token in tokens:
+        yield aisdk.text(token + " ")
+        await asyncio.sleep(0.01)
+    yield aisdk.finish()
 
 @router.post("/chat/completions")
 async def chat_completions(
     request: Request,
     user: OptionalUserDep,
     db: SessionDep,
-    checkpointer: CheckPointerDep,
 ):
     """以兼容 openai completions 协议的方式 反代其他 ai 提供商的 completions api"""
 
@@ -54,27 +65,103 @@ async def chat_completions(
 
     is_stream = request_data.get("stream")
     model = request_data.get("model") or default_llm_model
-    is_chat = request_data.get("isChat")
+    is_chat = request.headers.get("X-Chat") == "1" or request_data.get("isChat")
 
     request_data["model"] = model
+    messages = request_data.get("messages")
     if not is_chat:
         # open ai 兼容的模型调用
-        if request_data.get("messages"):
-            if is_stream:
-                response = StreamingResponse(
-                    chat_completions_stream_generator(request_data),
-                    media_type="text/event-stream",
-                )
-                return response
-
-            else:
-                response = await call_chat_completions(request_data)
-                return response
-        else:
+        if not messages:
             return HTTPException(status_code=503, detail="No messages provided")
+        if is_stream:
+            return StreamingResponse(
+                chat_completions_stream_generator(request_data),
+                media_type="text/event-stream",
+            )
+
+        else:
+            return await call_chat_completions(request_data)
+
+    # return aisdk.AiSDKStreamResponse(
+    #     fake_video_streamer(),
+    # )
+    return StreamingResponse(
+        fake_video_streamer(),
+        media_type="text/event-stream",
+        headers={
+            # "x-vercel-ai-data-stream": "v1",
+            "Content-Type": "text/plain; charset=utf-8",
+            "Vary": "RSC, Next-Router-State-Tree, Next-Router-Prefetch",
+            "Cache-Control": "no-store, no-cache, must-revalidate, proxy-revalidate",
+            "Pragma": "no-cache",
+            "Expires": "0",
+            "Surrogate-control": "no-store",
+        },
+    )
 
 
 
+
+example_stream_response = """
+我将为你创建一个最简单的配置。我将使用 Vite 来快速搭建一个简单的 HTML 和 JavaScript 项目。这是一个入门级的开发环境，非常适合简单的项目。
+
+<boltArtifact id="simple-vite-project" title="创建最简单的 Vite 项目">
+<boltAction type="file" filePath="package.json">
+{
+  "name": "simple-project",
+  "private": true,
+  "version": "0.0.0",
+  "type": "module",
+  "scripts": {
+    "dev": "vite",
+    "build": "vite build",
+    "preview": "vite preview"
+  },
+  "devDependencies": {
+    "vite": "^4.3.9"
+  }
+}
+</boltAction>
+
+<boltAction type="file" filePath="index.html">
+<!DOCTYPE html>
+<html lang="en">
+  <head>
+    <meta charset="UTF-8" />
+    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
+    <title>简单项目</title>
+  </head>
+  <body>
+    <div id="app"></div>
+    <script type="module" src="/main.js"></script>
+  </body>
+</html>
+</boltAction>
+
+<boltAction type="file" filePath="main.js">
+document.querySelector('#app').innerHTML = `
+  <h1>你好，世界！</h1>
+  <p>这是一个最简单的 Vite 项目。</p>
+`
+</boltAction>
+
+<boltAction type="shell">
+<command>npm install && npm run dev</command>
+</boltAction>
+</boltArtifact>
+
+我已经为你创建了一个最简单的项目。这个项目包含以下内容：
+
+1. 一个基本的 HTML 文件（index.html）
+2. 一个简单的 JavaScript 文件（main.js）
+3. 一个 package.json 文件，用于配置项目依赖和脚本
+
+项目已经设置完成，开发服务器正在运行。你可以在浏览器中看到一个简单的网页，显示 "你好，世界！" 和一条简单的消息。
+
+这个项目为你提供了一个良好的起点。你可以根据需要修改 HTML 和 JavaScript 文件来扩展项目功能。如果你想添加样式，可以创建一个 CSS 文件并将其链接到 HTML 中。
+
+如果你有任何问题或者想要进一步开发这个项目，请随时告诉我！
+"""
 # import os
 # from shutil import rmtree
 
