@@ -61,3 +61,16 @@ async def embedding_hf(
 async def call_embedding_1024(content: str):
     result = await embedding_hf(inputs=[content])
     return result
+
+
+
+
+def get_default_embeddings():
+    from langchain_community.embeddings import HuggingFaceInferenceAPIEmbeddings
+
+    # llm_model_instance = get_llm_chatbot_default()
+    embedder_model_instance = HuggingFaceInferenceAPIEmbeddings(
+        api_key=settings.HUGGINGFACEHUB_API_TOKEN,
+        model_name="sentence-transformers/all-MiniLM-l6-v2",
+    )
+    return embedder_model_instance
\ No newline at end of file
