@@ -3,17 +3,11 @@ import logging
 import pprint
 import time
 from collections.abc import AsyncIterator, Generator
-from typing import TYPE_CHECKING
-
-if TYPE_CHECKING:
-    from langchain_core.messages import AIMessageChunk
-    from langchain_core.runnables import RunnableConfig
 
 from fastapi.encoders import jsonable_encoder
 from fastapi.responses import StreamingResponse
 from json_repair import repair_json
 from langchain_core.messages import BaseMessage
-from langgraph.graph.state import CompiledStateGraph
 from openai import Stream
 from openai.types.chat.chat_completion_chunk import (
     ChatCompletionChunk,
@@ -66,18 +60,6 @@ def chat_complations_stream_text(response: Stream[ChatCompletionChunk]):
             yield "[DONE]\n"
 
 
-# defaultModel = "groq/llama3-8b-8192"
-# default_model = "groq/llama3-groq-70b-8192-tool-use-preview"
-# groq_tokens = [
-#     "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",
-# ]
-
-
-def get_groq_api_token():
-    # return random.choice(groq_tokens)
-    return
-
-
 def stream_response(stream_chunck: Stream[ChatCompletionChunk]):
     def gen_stream():
         for chunk in stream_chunck:
@@ -229,26 +211,3 @@ def convert_to_openai_messages(messages: list[ClientMessage]):
         openai_messages.append({"role": message.role, "content": parts})
 
     return openai_messages
-
-
-# async def wf_to_chatstreams(wf: CompiledStateGraph, state, thread_id: str):
-#     config: RunnableConfig = {"configurable": {"thread_id": thread_id}}
-#     async for event in wf.astream_events(
-#         input=state,
-#         version="v2",
-#         config=config,
-#     ):
-#         kind = event["event"]
-#         name = event["name"]
-#         data = event["data"]
-#         if kind == "on_chat_model_stream":
-#             data_chunk: AIMessageChunk = event["data"]["chunk"]
-#             content = data_chunk.content
-#             yield f"0: {json.dumps(content)} \n\n"
-#         print(f"astream_event: kind: {kind}, name={name},{data}")
-
-#         if kind == "on_chain_end" and name == "LangGraph":
-#             # 完全结束可以拿到最终数据
-#             yield f"2: {json.dumps(jsonable_encoder(data))}\n"
-
-#     print(f"flow 结束, {thread_id}")
