@@ -46,7 +46,7 @@ def init_project():
 
     if settings.PREFECT_API_KEY:
         bash(f"prefect cloud login -k {settings.PREFECT_API_KEY}")
-        bash("prefect config set PREFECT_API_URL=\"http://127.0.0.1:4200/api\"")
+        bash('prefect config set PREFECT_API_URL="http://127.0.0.1:4200/api"')
         # bash("prefect server start")
 
     # if command_exists("cursor"):
@@ -132,8 +132,8 @@ def docker_build_base():
 
 
 async def run_deploy():
-    # await dp_vercel_mtmaiadmin()
-    await dp_vercel_mtmaifront()
+    await dp_vercel_mtmaiadmin()
+    # await dp_vercel_mtmaifront()
     await run_tmpbo_instance1()
     logger.info("✅ tembo io pushed")
     hf_trans1_commit()
@@ -144,12 +144,12 @@ async def run_deploy():
 
 py_projects = [
     "mtmai",
-    "mtmdb",
+    # "mtmdb",
     "mtmlib",
     "mtmtrain",
-    "mtmai-client",
+    # "mtmai-client",
     "mtmscreentocode",
-    "mtmflow",
+    # "mtmflow",
 ]
 
 
@@ -187,8 +187,8 @@ def release_py():
 def release_npm():
     npm_packages = [
         # "apps/mtmaiweb",
-        # "apps/mtmaiadmin",
-        "apps/mtmaifront",
+        "apps/mtmaiadmin",
+        # "apps/mtmaifront",
         "packages/mtmeditor",
         "packages/mtmscreentocode",
         "packages/mtxuilib",
