@@ -1,7 +1,7 @@
-import logging
+import asyncio
 import os
 import threading
-import asyncio
+
 from fastapi import APIRouter, FastAPI, Request
 from fastapi.concurrency import asynccontextmanager
 from fastapi.responses import JSONResponse
@@ -49,7 +49,6 @@ api_router.include_router(utils.router, prefix="/utils", tags=["utils"])
 api_router.include_router(items.router, prefix="/items", tags=["items"])
 api_router.include_router(blog.router, prefix="/posts", tags=["posts"])
 api_router.include_router(image.router, prefix="/image", tags=["image"])
-api_router.include_router(openai.router, tags=["openai"])
 api_router.include_router(train.router, prefix="/train", tags=["train"])
 api_router.include_router(webhook.router, prefix="/webhook", tags=["webhook"])
 api_router.include_router(metrics.router, prefix="/metrics", tags=["metrics"])
@@ -62,6 +61,8 @@ api_router.include_router(site.router, prefix="/site", tags=["site"])
 api_router.include_router(search.router, prefix="/search", tags=["search"])
 api_router.include_router(webpage.router, prefix="/webpage", tags=["webpage"])
 api_router.include_router(tasks.router, prefix="/tasks", tags=["tasks"])
+api_router.include_router(openai.router, tags=["openai"])
+
 
 if not is_in_vercel():
     from mtmai.api import admin
@@ -204,6 +205,10 @@ async def serve():
         port=settings.PORT,
         log_level="info",
         reload=not settings.is_production,
+        # !!! bug 当 使用了prefect 后，使用了这个指令： @flow，程序会被卡在： .venv/lib/python3.12/site-packages/uvicorn/config.py
+        # !!!365行：logging.config.dictConfig(self.log_config)
+        # !!! 原因未知，但是 log_config=None 后，问题消失
+        log_config=None,
     )
     host = (
         "127.0.0.1"
@@ -230,13 +235,13 @@ def start_deamon_serve():
         and not is_in_huggingface()
         and not is_in_windows()
     ):
-
         from mtmlib import tunnel
 
         threading.Thread(target=lambda: asyncio.run(tunnel.start_cloudflared())).start()
 
         if not is_in_vercel() and not settings.is_in_gitpod:
             from mtmai.mtlibs.server.searxng import run_searxng_server
+
             threading.Thread(target=run_searxng_server).start()
         if (
             not settings.is_in_vercel
